@@ -1,5 +1,5 @@
 
 
 colTabulate <- function(x, max_number = max(x)) {
-  .Call('Rfast_coltabulate',x,max_number)
+  .Call('Rfast_col_tabulate',x,max_number)
 }
\ No newline at end of file
