@@ -1,9 +1,6 @@
 rayleigh.mle <- function(x) {
- 
   n <- length(x)
-  sigma <- sum(x^2) / n / 2
+  sigma <- 0.5 * sum(x^2) / n
   loglik <- sum( log(x) ) - n * log(sigma) - n
-  
   list(loglik = loglik, sigma = sigma)
-
 }
\ No newline at end of file
