@@ -1,23 +1,23 @@
 //Author: Manos Papadakis
 
 #include <RcppArmadillo.h>
-#include <vector>
 #include "mn.h"
 
-using namespace std;
+using namespace Rcpp;
 
 //[[Rcpp::export]]
-vector<double> floyd_john(int n,vector<double> x){
-  i4mat_floyd(n,x);
-  return x;
+NumericVector floyd_john(const int n,NumericVector x){
+	NumericVector y=clone(x);
+  i4mat_floyd(n,y);
+  return y;
 }
 
 RcppExport SEXP Rfast_floyd_john(SEXP nSEXP,SEXP xSEXP){
 BEGIN_RCPP
     RObject __result;
     RNGScope __rngScope;
-    traits::input_parameter< int >::type n(nSEXP);
-    traits::input_parameter< vector<double> >::type x(xSEXP);
+    traits::input_parameter< const int >::type n(nSEXP);
+    traits::input_parameter< NumericVector >::type x(xSEXP);
     __result = wrap(floyd_john(n,x));
     return __result;
 END_RCPP
