@@ -26,8 +26,8 @@ END_RCPP
 }
 
 //[[Rcpp::export]]
-bool is_element_string(vector<string> x,string el){
-  vector<string>::iterator a=x.begin();
+bool is_element_string(CharacterVector x,basic_string<char> el){
+  CharacterVector::iterator a=x.begin();
   for(;a!=x.end() && *a!=el;++a);
   return *a==el;
 }
@@ -36,8 +36,8 @@ RcppExport SEXP Rfast_is_element_string(SEXP xSEXP,SEXP elSEXP){
 BEGIN_RCPP
     RObject __result;
     RNGScope __rngScope;
-    traits::input_parameter< vector<string> >::type x(xSEXP);
-    traits::input_parameter< string >::type el(elSEXP);
+    traits::input_parameter< CharacterVector >::type x(xSEXP);
+    traits::input_parameter< basic_string<char> >::type el(elSEXP);
     __result = wrap(is_element_string(x,el));
     return __result;
 END_RCPP
