@@ -31,7 +31,8 @@ vec regression_only(mat, colvec);
 double regression_only_col(colvec , colvec& );
 double digamma(double);
 double trigamma(double);
-void i4mat_floyd ( int,vector<double> &);
+void i4mat_floyd(int, NumericVector &);
+void i4mat_floyd_with_paths(const int, NumericVector&,NumericVector&);
 void min_max_d(double *,double *,double &, double &);
 void min_max_i(int *,int *,int &, int &);
 void max_d(double *,double *, double &);
@@ -57,7 +58,7 @@ umat design_matrix_helper_big(CharacterVector);
 colvec my_pow(colvec,const double);
 NumericVector minus_mean(NumericVector&,const double);
 NumericVector sqr(NumericVector&);
-NumericVector group_sum(NumericVector,IntegerVector,const int);
+NumericVector group_sum(NumericVector,IntegerVector,SEXP,SEXP);
 void minus_c(double f[],double &,double *,int,int &);
 double sumsqr(NumericMatrix &);
 IntegerVector Order(NumericVector,const bool,const bool);
@@ -73,4 +74,8 @@ IntegerVector combine(IntegerVector,IntegerVector);
 double med_helper(NumericVector::iterator,NumericVector::iterator);
 double total_euclidean_dist(NumericMatrix,const bool);
 NumericMatrix euclidean_dist(NumericMatrix,const bool);
+icolvec get_k_indices(rowvec,const int&);
+SEXP eachrow_min_abs(SEXP,SEXP);
+SEXP eachcol_min_abs(SEXP,SEXP);
+NumericVector Rank(NumericVector,string,const bool,const bool);
 #endif
